<?php
/*
 * Creastyle
 *
 * A simple ticket management system. 
 *
 * @package		Creastyle
 * @author		Creastyle
 * @link		http://www.creastyle.fr/Creastyle
 * @link		http://www.creastyle.fr
 */

class Index extends CI_Controller
{

	var $data = array();

	function __construct()
	{
		parent::__construct();
		$this -> _LoadData();

		$this -> load -> model('Client_model', 'Clients');
		$this -> data['title'] = "Service support client";

	}

	function index()
	{
		$this -> load -> template("index", $this -> data);
	}

	function _LoadData()
	{
		$departments = $this -> Admin -> ListDepartments();
		$this -> data['departments'] = $departments;
		
		$this->data['message'] = $this -> Admin -> GetNotificationMessage();
		

		$priorities = $this -> Admin -> ListPriorities();
		$this -> data['priorities'] = $priorities;
		if ($this -> input -> post('department'))
		{
			$departmentid = $this -> input -> post('department');
			$this -> data['departmentid'] = $departmentid;
		}
		else
		{
			$this -> data['departmentid'] = $this -> uri -> segment(3);
		}

		// Now we load all the additional fields in this department

		$additional_fields = $this -> Admin -> GetAdditionalFields($this -> data['departmentid']);
		$this -> data['additional'] = $additional_fields;

	}

	function openticket()
	{
		if (!$this -> uri -> segment(3))
		{
			$this -> data['error'] = 'Merci de sélectionner un service pour effectuer cette opération';
			$this -> index();
		}
		else
		{
			$this -> data['departmentid'] = $this -> uri -> segment(3);
			$this -> load -> template("openticket", $this -> data);
		}

	}

	function create()
	{
		$additional_fields = array();

		$body = $this -> input -> post('body');
		$department = $this -> input -> post('department');
		$email = $this -> input -> post('email');
		$priority = $this -> input -> post('priority');
		$subject = $this -> input -> post('subject');

		$this -> form_validation -> set_rules('email', 'Email', 'trim|required|valid_email');
		$this -> form_validation -> set_rules('subject', 'Subject', 'trim|required|max_length[30]');
		$this -> form_validation -> set_rules('body', 'Query', 'trim|required');
		$this -> form_validation -> set_rules('department', 'Department', 'required');

		// We fetch additional fields
		if (is_array($this -> data['additional']))
			foreach ($this->data['additional'] as $additional)
			{
				// We create these vales as an array
				$name = $additional['uniqid'];
				$additional_fields[$name] = $this -> encrypt -> encode($this -> input -> post($name));
			}

		if ($this -> form_validation -> run() == FALSE)
		{
			$this -> load -> template('openticket', $this -> data);
		}
		else
		{
			// Validation is success. So create ticket

			// Upload the file.
			if (isset($_FILES['userfile']))
				if (($_FILES['userfile']['name']) != '')
				{

					$config['upload_path'] = './attachments/';
					$config['allowed_types'] = 'gif|jpg|jpeg|pdf|png';
					$config['max_size'] = '5120';
					$config['max_width'] = '0';
					$config['max_height'] = '0';
					$config['encrypt_name'] = TRUE;
					$config['remove_spaces'] = TRUE;
					$this -> load -> library('upload', $config);

					if (!$this -> upload -> do_upload())
					{
						$this -> data['error'] = $this -> upload -> display_errors();
						$this -> load -> template('openticket', $this -> data);
						die();
					}

					$data = $this -> upload -> data();

					if (is_array($data))

						$attachment = $data['file_name'];
				}

			// Add user to the user table
			$add['email'] = $email;
			$clientid = $this -> Clients -> AddClient($add);

			$insert = array(
				'subject' => $subject,
				'department' => $department,
				'clientid' => $clientid,
				'priority' => $priority,
				'body' => $body,
				'status' => 'open'
			);

			if (isset($attachment))
				$insert['attachment'] = $attachment;

			// If additonal fields are posted, we json_encode it and save the values in a
			// column called 'additional'
			if (is_array($additional_fields))
				$insert['additional'] = json_encode($additional_fields);

			$this -> db -> insert('tbltickets', $insert);
			$ticketid = $this -> db -> insert_id();

			if ($this -> db -> affected_rows())
			{
				// 1. Send notification to admin
				// 2. Redirect the user to the ticket list page

				$clientdetails = $this -> Clients -> GetClientData($clientid);
				$clienthash = $clientdetails['hash'];

				// Send mail to the ticket submitter

				$ticket_link = site_url() . '/tickets/viewticket/' . $clienthash . '/' . $ticketid;
				$this -> load -> model("Emails");
				$companyname = $this -> Emails -> GetSetting('companyname');

				$body = "
				
				Bonjour $email,<br><br>
				
				Vous avez ouvert un ticket sur notre système de support.<br><br> 
				
				Ticket nr #$ticketid<br>
				Statut : Ouvert<br><br>
				
				Cliquez sur le lien ci-dessous pour voir les détails du ticket et poster des commentaires supplémentaires.<br><br>
				
				<a href=\"$ticket_link\">$ticket_link</a><br><br>
				
				Cordialement<br>
				$companyname
				
				";

				$this -> Emails -> SendMail($email, "Ticket #$ticketid Créé", $body);

				// Now we send emails to staff

				$staffs = $this -> Admin -> ListStaffs();
				$link = site_url() . '/admin/tickets/view/' . $ticketid;
				$subject = "Ticket #$ticketid Opened";
				$companyname = $this -> Emails -> GetSetting('companyname');
				$body = "
		
		Ticket #$ticketid a été créé par un client. Vous pouvez voir le ticket en cliquant sur le lien suivant <br><br>
		
		Email du client : $email<br><br>
		
		<a href=\"$link\">$link</a> <br><br>
		
		Cordialement<br>
		$companyname
		";

				foreach ($staffs as $staff)
				{
					$this -> Emails -> SendMail($staff['email'], $subject, $body);
				}

				$this -> data['success'] = 'Ticket créé avec succès. Vous recevrez une réponse automatique qui contiendra le lien pour suivre votre ticket';
				$this -> index();
			}

		}

	}

	function mytickets()
	{
		$clienthash = $this -> session -> userdata('clienthash');
		if (!isset($clienthash))
			die('Vous n\êtes pas connecté. Cliquez sur le lien de du ticket pour vous connecter automatiquement');

		$clientid = $this -> Clients -> GetClientIDFromHash($clienthash);

		if ($clientid == FALSE)
			die("Id client fourni invalide");

		$this -> data['tickets'] = $this -> Clients -> GetTicketsOfClient($clientid);
		$this -> data['title'] = 'Mes tickets';
		$this -> data['clienthash'] = $clienthash;
		$this -> load -> template('mytickets', $this -> data);

	}

}
